# BlackholeCalc

BlackholeCalc is a Python library for analyzing black hole thermodynamics and geometry.

## Features
* Calculate **Event Horizon** radius (Schwarzschild and Kerr metrics).
* Calculate **Hawking Radiation** temperature.
* Estimate **Accretion Disk** luminosity.

## Installation

```bash
pip install git+[https://github.com/aditya-roy-oops/blackholecalc.git](https://github.com/aditya-roy-oops/blackholecalc.git)